==> payara-embedded-all-5.2022.5-sources.jar: fish/payara/microprofile/restclient/RestClientServletContainerInitializerBlacklist.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2021 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package fish.payara.microprofile.restclient;

import org.eclipse.microprofile.rest.client.inject.RegisterRestClient;
import fish.payara.web.loader.ServletContainerInitializerBlacklist;

import javax.servlet.ServletContainerInitializer;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * Extension point that omits {@link ServletContainerInitializer ServletContainerInitializers} annotated with
 * {@link RegisterRestClient}. If we try and initialise these interfaces Jersey will fail them on validation (correctly)
 * since you will end up with a duplicate mapping (the interface itself against the actual endpoint implementation).
 *
 * Using an extension mechanism rather than having this check directly in
 * {@link org.glassfish.web.loader.ServletContainerInitializerUtil} allows us to avoid pulling MicroProfile APIs into
 * the core server as a dependency.
 *
 * @author Andrew Pielage
 */
public class RestClientServletContainerInitializerBlacklist implements ServletContainerInitializerBlacklist {

    @Override
    public void removeServletContainerInitializers(Map<Class<? extends ServletContainerInitializer>,
            Set<Class<?>>> initializerMap) {

        for (Map.Entry<Class<? extends ServletContainerInitializer>, Set<Class<?>>> e : initializerMap.entrySet()) {
            Class<? extends ServletContainerInitializer> initializer = e.getKey();

            if (e.getValue() != null) {
                // Don't try to initialise MicroProfile Rest Client interfaces as servlets
                initializerMap.put(initializer,
                        initializerMap.get(initializer).stream()
                                .filter(clazz -> !clazz.isAnnotationPresent(RegisterRestClient.class))
                                .collect(Collectors.toSet()));
            }
        }
    }
}

==> payara-embedded-all-6.2023.6-sources.jar: fish/payara/microprofile/restclient/RestClientServletContainerInitializerBlacklist.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2021-2022 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package fish.payara.microprofile.restclient;

import org.eclipse.microprofile.rest.client.inject.RegisterRestClient;
import fish.payara.web.loader.ServletContainerInitializerBlacklist;

import jakarta.servlet.ServletContainerInitializer;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * Extension point that omits {@link ServletContainerInitializer ServletContainerInitializers} annotated with
 * {@link RegisterRestClient}. If we try and initialise these interfaces Jersey will fail them on validation (correctly)
 * since you will end up with a duplicate mapping (the interface itself against the actual endpoint implementation).
 *
 * Using an extension mechanism rather than having this check directly in
 * {@link org.glassfish.web.loader.ServletContainerInitializerUtil} allows us to avoid pulling MicroProfile APIs into
 * the core server as a dependency.
 *
 * @author Andrew Pielage
 */
public class RestClientServletContainerInitializerBlacklist implements ServletContainerInitializerBlacklist {

    @Override
    public void removeServletContainerInitializers(Map<Class<? extends ServletContainerInitializer>,
            Set<Class<?>>> initializerMap) {

        for (Map.Entry<Class<? extends ServletContainerInitializer>, Set<Class<?>>> e : initializerMap.entrySet()) {
            Class<? extends ServletContainerInitializer> initializer = e.getKey();

            if (e.getValue() != null) {
                // Don't try to initialise MicroProfile Rest Client interfaces as servlets
                initializerMap.put(initializer,
                        initializerMap.get(initializer).stream()
                                .filter(clazz -> !clazz.isAnnotationPresent(RegisterRestClient.class))
                                .collect(Collectors.toSet()));
            }
        }
    }
}
